@@ -1,3 +1,6 @@
+"""
+Module contains definition of help strategy
+"""
 from lxml.etree import ElementTree
 from pygalgen.generator.common.params.argument_parser_conversion import \
     obtain_and_convert_parser
@@ -9,14 +12,17 @@ import io
 
 
 class HelpStrategy(Strategy):
+    """
+    This strategy extracts argument parser from target source code,
+    and uses it to generate help section
+    """
     STAGE = StrategyStage.HELP
 
     def __init__(self, args: Any, macros: Macros):
         super().__init__(args, macros, self.STAGE)
 
-    def apply_strategy(self, xml_output: ElementTree,
-                       file_path: str, module_name: str) -> Any:
-        parser = obtain_and_convert_parser(file_path)
+    def apply_strategy(self, xml_output: ElementTree) -> Any:
+        parser = obtain_and_convert_parser(self.args.path)
 
         file_like = io.StringIO()
 
