@@ -1,39 +1,37 @@
+"""
+Main module of PyGalGen generator, responsible for defining default program
+ arguments and program execution
+"""
 import argparse
 import sys
+from typing import List
+
 from pygalgen.generator.pipeline import PipelineExecutor
 from pygalgen.generator.plugin_discovery import discover_plugins
 import logging
 import pygalgen.generator.default_plugins
 import importlib.resources as res
 
-def define_default_params():
+def define_default_params() -> argparse.ArgumentParser:
+    """
+    Function creates argument parser and initializes default arguments
+
+    Returns
+    -------
+    parser : ArgumentParser
+     parser object initialized with default program arguments
+    """
     parser = argparse.ArgumentParser("Command parser")
     default = parser.add_argument_group("Default program parameters")
-    default.add_argument("--package-name", required=True, type=str,
-                         help="Name of the package for which you are "
-                              "creating the tool definition file")
 
-    default.add_argument("--package-version", type=str, required=True,
-                         help="Version of the package")
-
-    default.add_argument("--bundle", action="store_true", default=False,
-                         help="If this argument is set, argument '--path' "
-                              "will point to root directory of tool bundle "
-                              "you want to parse")
     default.add_argument("--path",
-                         help="Path to the source file / directory",
+                         help="Path to the source file",
                          required=True)
 
-    default.add_argument("--tool-name-map", required=False, type=str,
-                         default="",
-                         help="Comma separated list of file names and tool "
-                              "names, used in tool discovery if '--bundle' "
-                              "param is set. Format: file_name:tool_name,...")
-
-    default.add_argument("--inputs", type=str,
-                         help="Comma separated list of names and format types"
-                              " of arguments that contain paths to input files",
-                         default="")
+    default.add_argument("--tool-name", required=True, type=str,
+                                help="Name of the package for which you "
+                                     "are "
+                                     "creating the tool definition file")
 
     logging_grp = parser.add_argument_group("Logging arguments")
 
@@ -53,7 +51,19 @@ def define_default_params():
 # but it's necessary
 # to load plugins, plugin directory path has to be known, argument parsing of
 # argparse object happens after plugin loading. Because of this problem,
-def obtain_plugins_path(args):
+def obtain_plugins_path(args: List[str]) -> str:
+    """
+    Manually extracts --plugins-path from arguments. The manual extraction is
+    necessary, because this value is needed before argumenParser
+    can parse arguments
+    Parameters
+    ----------
+    args : List[str]
+
+    Returns
+    -------
+    Path to plugins directory
+    """
     for i, item in enumerate(args):
         if item == "--plugins-path" and i + 1 < len(args):
             return args[i + 1]
@@ -62,6 +72,16 @@ def obtain_plugins_path(args):
 
 
 def main(args):
+    """
+    Main function of PyGalGen generator
+    Parameters
+    ----------
+    args : list of command line arguments:
+
+    Returns
+    -------
+    Error code
+    """
     logging.basicConfig(level=logging.DEBUG)
 
     parser = define_default_params()
