@@ -1,11 +1,15 @@
+"""
+Module responsible for plugin discovery, configuration and initialization
+"""
 import importlib
 import importlib.util
 import pkgutil
 import inspect
+import sys
 from importlib.abc import Traversable
 
 from pygalgen.generator.pluggability.plugin import Plugin
-from typing import Any, Union
+from typing import Any, Union, List
 import os
 import yaml
 import logging
@@ -15,12 +19,38 @@ class PluginDiscoveryException(Exception):
     pass
 
 
-def get_plugin_configuration(config_file_path) -> dict[str, Any]:
+def get_plugin_configuration(config_file_path: str) -> dict[str, Any]:
+    """
+
+    Parameters
+    ----------
+    config_file_path : str
+
+    Returns
+    -------
+    Dictionary containing parsed yml file
+
+    """
     with open(config_file_path, "r", encoding="utf-8") as file:
         return yaml.safe_load(file)
 
 
 def load_plugin(configuration: dict[str, Any], plugin_dir: str) -> Plugin:
+    """
+    The function initializes plugin based on provided configuration and path
+
+    Parameters
+    ----------
+    configuration : dict[str, Any]
+     parsed configuration yaml
+    plugin_dir : str
+     path to the root directory of plugin
+
+    Returns
+    -------
+    plugin : Plugin
+     initialized plugin object
+    """
     plugin_dct = configuration["plugin"]
 
     installed_modules = set(name for _, name, _ in pkgutil.iter_modules())
@@ -33,10 +63,14 @@ def load_plugin(configuration: dict[str, Any], plugin_dir: str) -> Plugin:
                             f"can't be satisfied")
             raise PluginDiscoveryException()
 
-    _, module_name = os.path.split(plugin_dct["path"])
+    path_to_module, module_name = os.path.split(plugin_dct["path"])
     module_name = os.path.splitext(module_name)[0]
     file_path = os.path.join(plugin_dir, plugin_dct["path"])
 
+    # Beware, what follows is a revoltingly dirty hack to solve import problems
+    plugin_module_dir_path = os.path.join(plugin_dir, path_to_module)
+    sys.path.append(plugin_module_dir_path)
+
     spec = importlib.util.spec_from_file_location(module_name, file_path)
     module = importlib.util.module_from_spec(spec)
 
@@ -60,10 +94,37 @@ def load_plugin(configuration: dict[str, Any], plugin_dir: str) -> Plugin:
                         f" {plugin_dct['path']}")
         raise PluginDiscoveryException()
 
-    return classes[0](os.path.join(plugin_dir, plugin_dct["assets"]))
+    assets_path = None
+    if "assets" in plugin_dct and plugin_dct["assets"] is not None:
+        assets_path = os.path.join(plugin_dir, plugin_dct["assets"])
+
+    return classes[0](plugin_dct.get("order", 0), plugin_dct["name"],
+                      assets_path)
 
 
-def discover_plugins(path: Union[str, Traversable]):
+def discover_plugins(path: Union[str, Traversable]) -> List[Plugin]:
+    """
+    Function traverses directory structure with path as a root and loads
+    all discovered plugins
+    The plugins have to have valid configuration file to be
+
+    Parameters
+    ----------
+    path : Union[str, Traversable]
+     path to the root directory of plugins
+
+    Returns
+    -------
+    result : List[Plugin]
+     list of initialized plugins
+
+    Raises
+    -------
+    FileNotFoundError
+     raises FileNotFoundError in case plugin configuration points
+     to missing plugin module
+
+    """
     try:
         result = []
         for path, _, files in os.walk(path):
